# $Id: unixkeys.tcl 87 2008-01-08 02:24:40Z kostix $
# "Unixkeys" -- plugin for Tkabber.
# Provides keybindings in Tk Text widgets which are familiar
# to Unix users: they resemble "canonical" bindings found in
# readline and Emacs.
# Written by Konstantin Khomoutov <flatworm@users.sourceforge.net>
# See INSTALL for installation procedure.
# See README for usage guidelines.
# See license.terms for details on usage and distribution.


namespace eval unixkeys {
	foreach mod {Alt Meta} {
		bind Text <$mod-a> [bind Text <Control-Key-Home>]
		bind Text <$mod-e> [bind Text <Control-Key-End>]
	}

	foreach mod {Alt Meta} {
		bind Text <$mod-b> [bind Text <Control-Key-Left>]
		bind Text <$mod-f> [bind Text <Control-Key-Right>]
	}

	bind Text <Control-u> { %W delete {insert linestart} insert}

	foreach {mod key} {Alt BackSpace Control w} {
		bind Text <$mod-Key-$key> { %W delete [tk::TextPrevPos %W insert tcl_startOfPreviousWord] insert }
	}

	foreach key {d Delete} {
		foreach mod {Alt Meta} {
			bind Text <$mod-Key-$key> { %W delete insert [::tk::TextNextPos %W insert tcl_endOfWord] }
		}
	}

	if {[string equal $::tcl_platform(os) windows]} {
		event add <<Undo>> <Control-Key-underscore>
	}
	event add <<Undo>> <Control-Key-x><Control-Key-u>

	bind Text <Control-backslash> { %W tag add sel 1.0 end }
	bind Text <Control-Key-x><h> { %W tag add sel 1.0 end }
}

namespace delete unixkeys

